@@ -2,11 +2,8 @@
 
 set -e
 
-PREFIX=$1
+PREFIX=${1:-/usr/local}
 ETCPREFIX=$2
-if [ -z $PREFIX ]; then
-  PREFIX=/usr/local
-fi
 
 
 BINDIR=$PREFIX/bin
@@ -18,7 +15,7 @@ PROFILEDIR=$CONFDIR/profile.d
 mkdir -p $BINDIR || true
 cp -fv grc grcat $BINDIR
 mkdir -p $LIBDIR || true
-cp -fv conf.* $LIBDIR
+cp -fv colourfiles/conf.* $LIBDIR
 mkdir -p $MANDIR/man1
 cp -fv grc.1 $MANDIR/man1
 cp -fv grcat.1 $MANDIR/man1
@@ -27,3 +24,4 @@ cp -fv grc.conf $CONFDIR
 mkdir -p $PROFILEDIR
 cp -fv grc.bashrc $PROFILEDIR
 
+
